"use client"

import { CreateGweetWrapper } from "@/components/create-gweet/components/create-gweet-wrapper";
import LoadingItem from "@/components/loading-item";
import { TryAgain } from "@/components/try-again";
import { Card } from "@/components/ui/card";
import { Separator } from "@/components/ui/separator";
import Image from "next/image";
import { usePathname } from "next/navigation";
import { useGweet } from "../hooks/use-gweet";
import { Comments } from "./comments";
import { GweetActions } from "./gweet-actions";
import { GweetAuthor } from "./gweet-author";
import { GweetCreationDate } from "./gweet-creation-date";

export const GweetDetails = () => {
    // TODO use params
    const pathname = usePathname();
    const id = pathname?.split(`/`)[3] || ``;

    const { data: gweet, isLoading, isError } = useGweet(id);

    if (isLoading) {
        return <LoadingItem />;
    }

    if (isError) {
        return <TryAgain />;
    }

    if (!isLoading && !isError && !gweet) {
        return <>Not Found!</>
    }

    return (
        <>
            <div className="flex flex-col space-y-3 px-3 pt-3">
                <GweetAuthor gweet={gweet} />

                {/* TODO needs handling of all gweets above and under the gweet */}

                <div className="flex flex-col space-y-3">
                    {gweet.content && <h1 className="break-words">{gweet.content}</h1>}

                    {/* TODO make own component */}
                    {gweet.media.length > 0 && (
                        <div className={`grid object-cover h-[600px] ${gweet.media.length === 1 ? "grid-cols-1"
                            : gweet.media.length === 2 ? "grid-cols-2 gap-3"
                                : gweet.media.length === 3 || 4 ? "grid-cols-2 grid-rows-2 gap-3"
                                    : ""
                            }`}
                        >
                            {gweet.media.map((image, i) => {
                                const isFirstImage = gweet.media.length === 3 && i === 0;
                                return (
                                    <Card key={i} className={`relative max-h-[600px] overflow-hidden ${isFirstImage ? "row-span-2" : ""}`}>
                                        <Image
                                            src={image.url as string}
                                            alt="gweet image"
                                            fill
                                            className="object-cover rounded-lg"
                                        />
                                    </Card>
                                );
                            })}
                        </div>
                    )}

                    {/* TODO */}
                    {/* {gweet?.quotedGweet && <QuotedGweet gweet={gweet?.quotedGweet} />} */}
                </div>

                <div className="flex flex-col items-center flex-wrap flex-grow sm:flex-row space-y-3 sm:space-y-0">
                    <div className="flex-grow text-muted-foreground">
                        <GweetCreationDate date={gweet.createdAt} />
                    </div>
                    <div className="sm:items-end">
                        <GweetActions gweet={gweet} />
                    </div>
                </div>

                <CreateGweetWrapper replyToGweetId={gweet?.id} />
            </div>
            <Separator className="h-1 mb-3" />
            <Comments gweetId={gweet?.id} />
        </>
    );
};